import simple
import double_class

class Test:
    def a(self):
        return b(x)
    def b(self):
        return min(a())
    def c(self):
        print f('ciao')
    def d(self):
        return b() 

class Prova:
    def __init__(self):
        pass
    def x(self):
        return double_class.f4()
    def y(self):
        return b(self)
    def z(self):
        return double_class.g4()

def f(x):
    return simple.piece_of_cake()

def g(x):
    return g(f(x))
